← Back to team overview

dhis2-devs team mailing list archive

[Branch ~dhis2-devs-core/dhis2/trunk] Rev 793: Minor fix.

 

------------------------------------------------------------
revno: 793
committer: Lars Helge Oeverland larshelge@xxxxxxxxx
branch nick: trunk
timestamp: Mon 2009-09-28 19:18:13 +0200
message:
  Minor fix.
modified:
  dhis-2/dhis-web/dhis-web-maintenance/dhis-web-maintenance-dataadmin/src/main/java/org/hisp/dhis/dataadmin/action/lock/GetDataSetsForLockAction.java
  dhis-live/src/main/java/org/hisp/dhis/TrayApp.java
  dhis-live/src/main/java/org/hisp/dhis/WebAppServer.java


--
lp:dhis2
https://code.launchpad.net/~dhis2-devs-core/dhis2/trunk

Your team DHIS 2 developers is subscribed to branch lp:dhis2.
To unsubscribe from this branch go to https://code.launchpad.net/~dhis2-devs-core/dhis2/trunk/+edit-subscription.
=== modified file 'dhis-2/dhis-web/dhis-web-maintenance/dhis-web-maintenance-dataadmin/src/main/java/org/hisp/dhis/dataadmin/action/lock/GetDataSetsForLockAction.java'
--- dhis-2/dhis-web/dhis-web-maintenance/dhis-web-maintenance-dataadmin/src/main/java/org/hisp/dhis/dataadmin/action/lock/GetDataSetsForLockAction.java	2009-09-20 17:27:54 +0000
+++ dhis-2/dhis-web/dhis-web-maintenance/dhis-web-maintenance-dataadmin/src/main/java/org/hisp/dhis/dataadmin/action/lock/GetDataSetsForLockAction.java	2009-09-28 17:18:13 +0000
@@ -70,7 +70,7 @@
     {
         this.dataSetLockService = dataSetLockService;
     }
-    
+
     private SelectionTreeManager selectionTreeManager;
 
     public void setSelectionTreeManager( SelectionTreeManager selectionTreeManager )
@@ -111,19 +111,20 @@
             {
                 if ( dataSetLockService.getDataSetLockByDataSetAndPeriod( dataSet, period ) != null )
                 {
-                	if( dataSetLockService.getDataSetLockByDataSetAndPeriod( dataSet, period ).getSources() != null )
-                	{
-	                    dataSet.setLocked( true );
-	                    dataSetService.updateDataSet( dataSet );
-	                    dataSets.add( dataSet );
-                	}
-                	else
-                	{                                                
-	                    dataSetLockService.deleteDataSetLock( dataSetLockService.getDataSetLockByDataSetAndPeriod( dataSet, period ) );
-	                    dataSet.setLocked( false );
-	                    dataSetService.updateDataSet( dataSet );
-	                    dataSets.add( dataSet );
-                	}
+                    if ( dataSetLockService.getDataSetLockByDataSetAndPeriod( dataSet, period ).getSources() != null )
+                    {
+                        dataSet.setLocked( true );
+                        dataSetService.updateDataSet( dataSet );
+                        dataSets.add( dataSet );
+                    }
+                    else
+                    {
+                        dataSetLockService.deleteDataSetLock( dataSetLockService.getDataSetLockByDataSetAndPeriod(
+                            dataSet, period ) );
+                        dataSet.setLocked( false );
+                        dataSetService.updateDataSet( dataSet );
+                        dataSets.add( dataSet );
+                    }
                 }
                 else
                 {
@@ -132,8 +133,8 @@
                     dataSets.add( dataSet );
                 }
             }
-            //selectionTreeManager.clearLockOnSelectedOrganisationUnits();
-           // selectionTreeManager.clearSelectedOrganisationUnits();
+            // selectionTreeManager.clearLockOnSelectedOrganisationUnits();
+            // selectionTreeManager.clearSelectedOrganisationUnits();
         }
         return SUCCESS;
     }

=== modified file 'dhis-live/src/main/java/org/hisp/dhis/TrayApp.java'
--- dhis-live/src/main/java/org/hisp/dhis/WebAppServer.java	2009-09-11 16:47:31 +0000
+++ dhis-live/src/main/java/org/hisp/dhis/WebAppServer.java	2009-09-28 17:18:13 +0000
@@ -32,6 +32,7 @@
  */
 
 package org.hisp.dhis;
+
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.mortbay.component.LifeCycle;
--- dhis-live/src/main/java/org/hisp/dhis/TrayApp.java	2009-09-28 15:54:18 +0000
+++ dhis-live/src/main/java/org/hisp/dhis/TrayApp.java	2009-09-28 17:18:13 +0000
@@ -47,7 +47,7 @@
   private static final Log log = LogFactory.getLog( TrayApp.class );
   private static final String CONFIG_DIR = "/conf";
   private static final String STOPPED_ICON = "/icons/stopped.png";
-  private static final String STARTING_ICON = "/icons/starting.gif";
+  private static final String STARTING_ICON = "/icons/starting.png";
   private static final String FAILED_ICON ="/icons/failed.png";
   private static final String RUNNING_ICON = "/icons/running.png";
   
@@ -98,7 +98,7 @@
     MenuItem defaultItem = new MenuItem("Exit");
     popup.add(defaultItem);
 
-    trayIcon = new TrayIcon(image,"DHIS2 Lite", popup);
+    trayIcon = new TrayIcon(image,"DHIS 2 Live", popup);
     trayIcon.setImageAutoSize(true);
 
     ActionListener listener = new ActionListener() {
@@ -169,7 +169,7 @@
   public void lifeCycleStarted(LifeCycle arg0) {
     log.info("Lifecycle: server started");
     String url = "http://localhost:"; + appServer.getConnectorPort();
-    trayIcon.displayMessage("Started","DHIS2 is running. Point your\nbrowser to " + url + ".",TrayIcon.MessageType.INFO);
+    trayIcon.displayMessage("Started","DHIS 2 is running. Point your\nbrowser to " + url + ".",TrayIcon.MessageType.INFO);
     trayIcon.setToolTip("DHIS 2 Server running");
     trayIcon.setImage(createImage(RUNNING_ICON, "Running icon"));
     try {
@@ -247,7 +247,7 @@
 
   /**
    *  The <code>getInstallDir</code> method is a hack to determine the current
    *  directory the dhis2 lite package is installed in.  It does this by finding
    *  the file URL of a resource within the executable jar and extracting the 
    *  installation path from that. 
    *
@@ -247,7 +247,7 @@
   /**
    *  The <code>getInstallDir</code> method is a hack to determine the current
-   *  directory the dhis2 lite package is installed in.  It does this by finding
+   *  directory the DHIS 2 Live package is installed in.  It does this by finding
    *  the file URL of a resource within the executable jar and extracting the 
    *  installation path from that. 

=== modified file 'dhis-live/src/main/java/org/hisp/dhis/WebAppServer.java'